@@ -678,6 +678,10 @@ class LibvirtBlockInfoTest(test.NoDBTestCase):
                 (arch.PPC, 'cdrom', 'scsi'),
                 (arch.PPC64, 'disk', 'virtio'),
                 (arch.PPC64, 'cdrom', 'scsi'),
+                (arch.PPCLE, 'disk', 'virtio'),
+                (arch.PPCLE, 'cdrom', 'scsi'),
+                (arch.PPC64LE, 'disk', 'virtio'),
+                (arch.PPC64LE, 'cdrom', 'scsi'),
                 (arch.S390, 'disk', 'virtio'),
                 (arch.S390, 'cdrom', 'scsi'),
                 (arch.S390X, 'disk', 'virtio'),
